@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONRIGHTSATTRIBUTE_P_H
-#define AKONADI_COLLECTIONRIGHTSATTRIBUTE_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 
@@ -16,6 +15,8 @@
 
 namespace Akonadi
 {
+class CollectionRightsAttributePrivate;
+
 /**
  * @internal
  *
@@ -63,11 +64,9 @@ public:
 
 private:
     /// @cond PRIVATE
-    class Private;
-    const std::unique_ptr<Private> d;
+    const std::unique_ptr<CollectionRightsAttributePrivate> d;
     /// @endcond
 };
 
 } // namespace Akonadi
 
-#endif
